/* Licensed Materials - Property of IBM            */
/* SupportPac CA87                                 */
/* (C) Copyright IBM Corp 1998 All Rights Reserved */
/* US Government Users Restricted Rights-Use,      */
/* duplication or disclosure resetricted by GSA ADP*/
/* Schedule Contract with IBM Corp.                */

/* RAHRMKIM exec */

/* This exec will run under OS/2 or NT Rexx */
/*                                          */
/* It provides the means whereby an image   */
/* (encoded in ASCII) can be placed inside  */
/* a Rexx/CICS exec which services image    */
/* requests.                                */
/*                                          */
/* It takes an image file and splits it     */
/* up into 30byte chunks encodec as ASCII   */
/* Hex strings all concatinated together.   */
/*                                          */
/* This is then written to a file which     */
/* can be copied as text up MVS and         */
/* then inserted in a Rexx/Cics exec that   */
/* will return an image.                    */
/*                                          */

/* It takes 2 parms p1 -> name of the image file to convert        */
/*                  p2 -> local name of file to contain conversion */
/* Grab and display the parameters */

parse arg p.1 p.2 p.3 p.4 p.5 p.6 p.7 p.8 p.9 p.10

p.0 = 0
do i = 1 to 10
   if (   ( p.i <> ''    ) ,
        & ( p.i <> ' '   ) ,
        & ( p.i <> 'P.'i ) )
          then do
               p.0 = i
               p.i = translate(strip(p.i,'B'))
               end
          else leave
   end

if ( p.0 <> 0 ) then do i = 1 to p.0
     say 'Parm' i '->' p.i
     end

/* The image is in parm1 and the output name in parm 2 */

wantimage = ''
wantname = ''
if ( p.0 >= 1 ) then wantimage = p.1
if ( p.0 >= 2 ) then wantname  = p.2

say 'Generating 'image 'into' wantname 'for Rexx/CICS usage'

/* Read the image */

maxsize = 100000

image  = CHARIN(wantimage,,maxsize)
imagel = length(image)
say 'Read in' imagel 'bytes'

/* empty the imageout area */

imageout = ''
crlf     = '0D0A'X

/* Small images can go via concatination which is quicker */

if ( imagel <= 15000 ) then do
 /* loop through small image in groups of 25 bytes via lots of concatinations */
 say 'Processing small image'
 do i = 1 to imagel by 25
    size = 25
    if ( (i+25) > imagel ) then do
         size = imagel - (i-1)
         end
    part  = substr(image,i,size)
    partx = c2x(part)
    if ( imageout = '' ) then do
         imageout = "image = '"partx"'X"
         end
         else do
         imageout = imageout','|| crlf || "||      '"partx"'X"
         end
    end
 end
else do
  /* loop through large image in groups of 25 bytes using variables */
 say 'Processing large image'
 imageout = 'image = copies('' '','imagel')'crlf
 imageout = imageout'image = '''''crlf

 do i = 1 to imagel by 25
    size = 25
    if ( (i+25) > imagel ) then do
         size = imagel - (i-1)
         end
    part     = substr(image,i,size)
    partx    = c2x(part)
    imageout = imageout"image = image'"partx"'X"crlf
    end
 end

say 'Built Hex string of length' length(imageout)
/* say imageout */

/* write out the generated string into the file */

say 'Writing String to' wantname
'@ERASE' wantname
rcc = stream(wantname,'C','OPEN WRITE')
rc  = charout(wantname,imageout)
rcc = stream(wantname,'C','CLOSE')
say 'File written with rc' rc 'Now ready for copying to MVS'

/* End of processing */
say 'End of RAHMKIM exec'
exit

/* end of RAHMKIM exec */
